@@ -4,13 +4,13 @@ from typing import Any, Dict, List, Optional, Union
 import httpx
 
 from ...client import Client
-from ...models.getv_3_users_activationapp_version_type_1 import Getv3UsersActivationappVersionType1
+from ...models.getv_3_users_activation_app_version_type_1 import Getv3UsersActivationAppVersionType1
 from ...models.getv_3_users_company_type_1 import Getv3UsersCompanyType1
 from ...models.getv_3_users_created_at_type_1 import Getv3UsersCreatedAtType1
 from ...models.getv_3_users_email_type_1 import Getv3UsersEmailType1
 from ...models.getv_3_users_last_seen_at_type_1 import Getv3UsersLastSeenAtType1
-from ...models.getv_3_users_metadatakey_type_1 import Getv3UsersMetadatakeyType1
-from ...models.getv_3_users_metadatavalue_type_1 import Getv3UsersMetadatavalueType1
+from ...models.getv_3_users_metadata_key_type_1 import Getv3UsersMetadataKeyType1
+from ...models.getv_3_users_metadata_value_type_1 import Getv3UsersMetadataValueType1
 from ...models.getv_3_users_role_type_1 import Getv3UsersRoleType1
 from ...models.getv_3_users_tag_type_1 import Getv3UsersTagType1
 from ...models.http_error_response_dto import HttpErrorResponseDto
@@ -30,24 +30,32 @@ def _get_kwargs(
     company: Union[Getv3UsersCompanyType1, None, Unset, str] = UNSET,
     tag: Union[Getv3UsersTagType1, None, Unset, str] = UNSET,
     tags: Union[Unset, None, List[str]] = UNSET,
-    metadatakey: Union[Getv3UsersMetadatakeyType1, None, Unset, str] = UNSET,
-    metadatavalue: Union[Getv3UsersMetadatavalueType1, None, Unset, str] = UNSET,
+    metadata_key: Union[Getv3UsersMetadataKeyType1, None, Unset, str] = UNSET,
+    metadata_value: Union[Getv3UsersMetadataValueType1, None, Unset, str] = UNSET,
     product_id: Union[Unset, None, str] = UNSET,
-    activationapp_version: Union[Getv3UsersActivationappVersionType1, None, Unset, str] = UNSET,
+    activation_app_version: Union[Getv3UsersActivationAppVersionType1, None, Unset, str] = UNSET,
     created_at: Union[Getv3UsersCreatedAtType1, None, Unset, datetime.datetime] = UNSET,
     last_seen_at: Union[Getv3UsersLastSeenAtType1, None, Unset, datetime.datetime] = UNSET,
     query: Union[Unset, None, str] = UNSET,
 ) -> Dict[str, Any]:
     url = "{}/v3/users".format(client.base_url)
 
-    headers: Dict[str, Any] = client.get_headers()
+    headers: Dict[str, str] = client.get_headers()
     cookies: Dict[str, Any] = client.get_cookies()
 
+    params: Dict[str, Any] = {}
+    params["page"] = page
+
+    params["limit"] = limit
+
+    params["sort"] = sort
+
     json_role: Union[Dict[str, Any], None, Unset, str]
     if isinstance(role, Unset):
         json_role = UNSET
     elif role is None:
         json_role = None
+
     elif isinstance(role, Getv3UsersRoleType1):
         json_role = UNSET
         if not isinstance(role, Unset):
@@ -56,11 +64,16 @@ def _get_kwargs(
     else:
         json_role = role
 
+    params["role"] = json_role
+
+    params["userType"] = user_type
+
     json_email: Union[Dict[str, Any], None, Unset, str]
     if isinstance(email, Unset):
         json_email = UNSET
     elif email is None:
         json_email = None
+
     elif isinstance(email, Getv3UsersEmailType1):
         json_email = UNSET
         if not isinstance(email, Unset):
@@ -69,11 +82,14 @@ def _get_kwargs(
     else:
         json_email = email
 
+    params["email"] = json_email
+
     json_company: Union[Dict[str, Any], None, Unset, str]
     if isinstance(company, Unset):
         json_company = UNSET
     elif company is None:
         json_company = None
+
     elif isinstance(company, Getv3UsersCompanyType1):
         json_company = UNSET
         if not isinstance(company, Unset):
@@ -82,11 +98,14 @@ def _get_kwargs(
     else:
         json_company = company
 
+    params["company"] = json_company
+
     json_tag: Union[Dict[str, Any], None, Unset, str]
     if isinstance(tag, Unset):
         json_tag = UNSET
     elif tag is None:
         json_tag = None
+
     elif isinstance(tag, Getv3UsersTagType1):
         json_tag = UNSET
         if not isinstance(tag, Unset):
@@ -95,6 +114,8 @@ def _get_kwargs(
     else:
         json_tag = tag
 
+    params["tag"] = json_tag
+
     json_tags: Union[Unset, None, List[str]] = UNSET
     if not isinstance(tags, Unset):
         if tags is None:
@@ -102,50 +123,64 @@ def _get_kwargs(
         else:
             json_tags = tags
 
-    json_metadatakey: Union[Dict[str, Any], None, Unset, str]
-    if isinstance(metadatakey, Unset):
-        json_metadatakey = UNSET
-    elif metadatakey is None:
-        json_metadatakey = None
-    elif isinstance(metadatakey, Getv3UsersMetadatakeyType1):
-        json_metadatakey = UNSET
-        if not isinstance(metadatakey, Unset):
-            json_metadatakey = metadatakey.to_dict()
+    params["tags"] = json_tags
+
+    json_metadata_key: Union[Dict[str, Any], None, Unset, str]
+    if isinstance(metadata_key, Unset):
+        json_metadata_key = UNSET
+    elif metadata_key is None:
+        json_metadata_key = None
+
+    elif isinstance(metadata_key, Getv3UsersMetadataKeyType1):
+        json_metadata_key = UNSET
+        if not isinstance(metadata_key, Unset):
+            json_metadata_key = metadata_key.to_dict()
 
     else:
-        json_metadatakey = metadatakey
+        json_metadata_key = metadata_key
 
-    json_metadatavalue: Union[Dict[str, Any], None, Unset, str]
-    if isinstance(metadatavalue, Unset):
-        json_metadatavalue = UNSET
-    elif metadatavalue is None:
-        json_metadatavalue = None
-    elif isinstance(metadatavalue, Getv3UsersMetadatavalueType1):
-        json_metadatavalue = UNSET
-        if not isinstance(metadatavalue, Unset):
-            json_metadatavalue = metadatavalue.to_dict()
+    params["metadata.key"] = json_metadata_key
+
+    json_metadata_value: Union[Dict[str, Any], None, Unset, str]
+    if isinstance(metadata_value, Unset):
+        json_metadata_value = UNSET
+    elif metadata_value is None:
+        json_metadata_value = None
+
+    elif isinstance(metadata_value, Getv3UsersMetadataValueType1):
+        json_metadata_value = UNSET
+        if not isinstance(metadata_value, Unset):
+            json_metadata_value = metadata_value.to_dict()
 
     else:
-        json_metadatavalue = metadatavalue
+        json_metadata_value = metadata_value
 
-    json_activationapp_version: Union[Dict[str, Any], None, Unset, str]
-    if isinstance(activationapp_version, Unset):
-        json_activationapp_version = UNSET
-    elif activationapp_version is None:
-        json_activationapp_version = None
-    elif isinstance(activationapp_version, Getv3UsersActivationappVersionType1):
-        json_activationapp_version = UNSET
-        if not isinstance(activationapp_version, Unset):
-            json_activationapp_version = activationapp_version.to_dict()
+    params["metadata.value"] = json_metadata_value
+
+    params["productId"] = product_id
+
+    json_activation_app_version: Union[Dict[str, Any], None, Unset, str]
+    if isinstance(activation_app_version, Unset):
+        json_activation_app_version = UNSET
+    elif activation_app_version is None:
+        json_activation_app_version = None
+
+    elif isinstance(activation_app_version, Getv3UsersActivationAppVersionType1):
+        json_activation_app_version = UNSET
+        if not isinstance(activation_app_version, Unset):
+            json_activation_app_version = activation_app_version.to_dict()
 
     else:
-        json_activationapp_version = activationapp_version
+        json_activation_app_version = activation_app_version
+
+    params["activation.appVersion"] = json_activation_app_version
 
     json_created_at: Union[Dict[str, Any], None, Unset, str]
     if isinstance(created_at, Unset):
         json_created_at = UNSET
     elif created_at is None:
         json_created_at = None
+
     elif isinstance(created_at, datetime.datetime):
         json_created_at = UNSET
         if not isinstance(created_at, Unset):
@@ -156,11 +191,14 @@ def _get_kwargs(
         if not isinstance(created_at, Unset):
             json_created_at = created_at.to_dict()
 
+    params["createdAt"] = json_created_at
+
     json_last_seen_at: Union[Dict[str, Any], None, Unset, str]
     if isinstance(last_seen_at, Unset):
         json_last_seen_at = UNSET
     elif last_seen_at is None:
         json_last_seen_at = None
+
     elif isinstance(last_seen_at, datetime.datetime):
         json_last_seen_at = UNSET
         if not isinstance(last_seen_at, Unset):
@@ -171,27 +209,14 @@ def _get_kwargs(
         if not isinstance(last_seen_at, Unset):
             json_last_seen_at = last_seen_at.to_dict()
 
-    params: Dict[str, Any] = {
-        "page": page,
-        "limit": limit,
-        "sort": sort,
-        "role": json_role,
-        "userType": user_type,
-        "email": json_email,
-        "company": json_company,
-        "tag": json_tag,
-        "tags": json_tags,
-        "metadata.key": json_metadatakey,
-        "metadata.value": json_metadatavalue,
-        "productId": product_id,
-        "activation.appVersion": json_activationapp_version,
-        "createdAt": json_created_at,
-        "lastSeenAt": json_last_seen_at,
-        "query": query,
-    }
+    params["lastSeenAt"] = json_last_seen_at
+
+    params["query"] = query
+
     params = {k: v for k, v in params.items() if v is not UNSET and v is not None}
 
     return {
+        "method": "get",
         "url": url,
         "headers": headers,
         "cookies": cookies,
@@ -250,14 +275,40 @@ def sync_detailed(
     company: Union[Getv3UsersCompanyType1, None, Unset, str] = UNSET,
     tag: Union[Getv3UsersTagType1, None, Unset, str] = UNSET,
     tags: Union[Unset, None, List[str]] = UNSET,
-    metadatakey: Union[Getv3UsersMetadatakeyType1, None, Unset, str] = UNSET,
-    metadatavalue: Union[Getv3UsersMetadatavalueType1, None, Unset, str] = UNSET,
+    metadata_key: Union[Getv3UsersMetadataKeyType1, None, Unset, str] = UNSET,
+    metadata_value: Union[Getv3UsersMetadataValueType1, None, Unset, str] = UNSET,
     product_id: Union[Unset, None, str] = UNSET,
-    activationapp_version: Union[Getv3UsersActivationappVersionType1, None, Unset, str] = UNSET,
+    activation_app_version: Union[Getv3UsersActivationAppVersionType1, None, Unset, str] = UNSET,
     created_at: Union[Getv3UsersCreatedAtType1, None, Unset, datetime.datetime] = UNSET,
     last_seen_at: Union[Getv3UsersLastSeenAtType1, None, Unset, datetime.datetime] = UNSET,
     query: Union[Unset, None, str] = UNSET,
 ) -> Response[Union[HttpErrorResponseDto, List[UserDto]]]:
+    """List all users
+
+     Returns a list of users. The users are returned sorted by creation date in ascending order.
+
+    Args:
+        page (Union[Unset, None, int]):
+        limit (Union[Unset, None, int]):
+        sort (Union[Unset, None, str]):
+        role (Union[Getv3UsersRoleType1, None, Unset, str]):
+        user_type (Union[Unset, None, str]):
+        email (Union[Getv3UsersEmailType1, None, Unset, str]):
+        company (Union[Getv3UsersCompanyType1, None, Unset, str]):
+        tag (Union[Getv3UsersTagType1, None, Unset, str]):
+        tags (Union[Unset, None, List[str]]):
+        metadata_key (Union[Getv3UsersMetadataKeyType1, None, Unset, str]):
+        metadata_value (Union[Getv3UsersMetadataValueType1, None, Unset, str]):
+        product_id (Union[Unset, None, str]):
+        activation_app_version (Union[Getv3UsersActivationAppVersionType1, None, Unset, str]):
+        created_at (Union[Getv3UsersCreatedAtType1, None, Unset, datetime.datetime]):
+        last_seen_at (Union[Getv3UsersLastSeenAtType1, None, Unset, datetime.datetime]):
+        query (Union[Unset, None, str]):
+
+    Returns:
+        Response[Union[HttpErrorResponseDto, List[UserDto]]]
+    """
+
     kwargs = _get_kwargs(
         client=client,
         page=page,
@@ -269,16 +320,16 @@ def sync_detailed(
         company=company,
         tag=tag,
         tags=tags,
-        metadatakey=metadatakey,
-        metadatavalue=metadatavalue,
+        metadata_key=metadata_key,
+        metadata_value=metadata_value,
         product_id=product_id,
-        activationapp_version=activationapp_version,
+        activation_app_version=activation_app_version,
         created_at=created_at,
         last_seen_at=last_seen_at,
         query=query,
     )
 
-    response = httpx.get(
+    response = httpx.request(
         verify=client.verify_ssl,
         **kwargs,
     )
@@ -298,15 +349,39 @@ def sync(
     company: Union[Getv3UsersCompanyType1, None, Unset, str] = UNSET,
     tag: Union[Getv3UsersTagType1, None, Unset, str] = UNSET,
     tags: Union[Unset, None, List[str]] = UNSET,
-    metadatakey: Union[Getv3UsersMetadatakeyType1, None, Unset, str] = UNSET,
-    metadatavalue: Union[Getv3UsersMetadatavalueType1, None, Unset, str] = UNSET,
+    metadata_key: Union[Getv3UsersMetadataKeyType1, None, Unset, str] = UNSET,
+    metadata_value: Union[Getv3UsersMetadataValueType1, None, Unset, str] = UNSET,
     product_id: Union[Unset, None, str] = UNSET,
-    activationapp_version: Union[Getv3UsersActivationappVersionType1, None, Unset, str] = UNSET,
+    activation_app_version: Union[Getv3UsersActivationAppVersionType1, None, Unset, str] = UNSET,
     created_at: Union[Getv3UsersCreatedAtType1, None, Unset, datetime.datetime] = UNSET,
     last_seen_at: Union[Getv3UsersLastSeenAtType1, None, Unset, datetime.datetime] = UNSET,
     query: Union[Unset, None, str] = UNSET,
 ) -> Optional[Union[HttpErrorResponseDto, List[UserDto]]]:
-    """Returns a list of users. The users are returned sorted by creation date in ascending order."""
+    """List all users
+
+     Returns a list of users. The users are returned sorted by creation date in ascending order.
+
+    Args:
+        page (Union[Unset, None, int]):
+        limit (Union[Unset, None, int]):
+        sort (Union[Unset, None, str]):
+        role (Union[Getv3UsersRoleType1, None, Unset, str]):
+        user_type (Union[Unset, None, str]):
+        email (Union[Getv3UsersEmailType1, None, Unset, str]):
+        company (Union[Getv3UsersCompanyType1, None, Unset, str]):
+        tag (Union[Getv3UsersTagType1, None, Unset, str]):
+        tags (Union[Unset, None, List[str]]):
+        metadata_key (Union[Getv3UsersMetadataKeyType1, None, Unset, str]):
+        metadata_value (Union[Getv3UsersMetadataValueType1, None, Unset, str]):
+        product_id (Union[Unset, None, str]):
+        activation_app_version (Union[Getv3UsersActivationAppVersionType1, None, Unset, str]):
+        created_at (Union[Getv3UsersCreatedAtType1, None, Unset, datetime.datetime]):
+        last_seen_at (Union[Getv3UsersLastSeenAtType1, None, Unset, datetime.datetime]):
+        query (Union[Unset, None, str]):
+
+    Returns:
+        Response[Union[HttpErrorResponseDto, List[UserDto]]]
+    """
 
     return sync_detailed(
         client=client,
@@ -319,10 +394,10 @@ def sync(
         company=company,
         tag=tag,
         tags=tags,
-        metadatakey=metadatakey,
-        metadatavalue=metadatavalue,
+        metadata_key=metadata_key,
+        metadata_value=metadata_value,
         product_id=product_id,
-        activationapp_version=activationapp_version,
+        activation_app_version=activation_app_version,
         created_at=created_at,
         last_seen_at=last_seen_at,
         query=query,
@@ -341,14 +416,40 @@ async def asyncio_detailed(
     company: Union[Getv3UsersCompanyType1, None, Unset, str] = UNSET,
     tag: Union[Getv3UsersTagType1, None, Unset, str] = UNSET,
     tags: Union[Unset, None, List[str]] = UNSET,
-    metadatakey: Union[Getv3UsersMetadatakeyType1, None, Unset, str] = UNSET,
-    metadatavalue: Union[Getv3UsersMetadatavalueType1, None, Unset, str] = UNSET,
+    metadata_key: Union[Getv3UsersMetadataKeyType1, None, Unset, str] = UNSET,
+    metadata_value: Union[Getv3UsersMetadataValueType1, None, Unset, str] = UNSET,
     product_id: Union[Unset, None, str] = UNSET,
-    activationapp_version: Union[Getv3UsersActivationappVersionType1, None, Unset, str] = UNSET,
+    activation_app_version: Union[Getv3UsersActivationAppVersionType1, None, Unset, str] = UNSET,
     created_at: Union[Getv3UsersCreatedAtType1, None, Unset, datetime.datetime] = UNSET,
     last_seen_at: Union[Getv3UsersLastSeenAtType1, None, Unset, datetime.datetime] = UNSET,
     query: Union[Unset, None, str] = UNSET,
 ) -> Response[Union[HttpErrorResponseDto, List[UserDto]]]:
+    """List all users
+
+     Returns a list of users. The users are returned sorted by creation date in ascending order.
+
+    Args:
+        page (Union[Unset, None, int]):
+        limit (Union[Unset, None, int]):
+        sort (Union[Unset, None, str]):
+        role (Union[Getv3UsersRoleType1, None, Unset, str]):
+        user_type (Union[Unset, None, str]):
+        email (Union[Getv3UsersEmailType1, None, Unset, str]):
+        company (Union[Getv3UsersCompanyType1, None, Unset, str]):
+        tag (Union[Getv3UsersTagType1, None, Unset, str]):
+        tags (Union[Unset, None, List[str]]):
+        metadata_key (Union[Getv3UsersMetadataKeyType1, None, Unset, str]):
+        metadata_value (Union[Getv3UsersMetadataValueType1, None, Unset, str]):
+        product_id (Union[Unset, None, str]):
+        activation_app_version (Union[Getv3UsersActivationAppVersionType1, None, Unset, str]):
+        created_at (Union[Getv3UsersCreatedAtType1, None, Unset, datetime.datetime]):
+        last_seen_at (Union[Getv3UsersLastSeenAtType1, None, Unset, datetime.datetime]):
+        query (Union[Unset, None, str]):
+
+    Returns:
+        Response[Union[HttpErrorResponseDto, List[UserDto]]]
+    """
+
     kwargs = _get_kwargs(
         client=client,
         page=page,
@@ -360,17 +461,17 @@ async def asyncio_detailed(
         company=company,
         tag=tag,
         tags=tags,
-        metadatakey=metadatakey,
-        metadatavalue=metadatavalue,
+        metadata_key=metadata_key,
+        metadata_value=metadata_value,
         product_id=product_id,
-        activationapp_version=activationapp_version,
+        activation_app_version=activation_app_version,
         created_at=created_at,
         last_seen_at=last_seen_at,
         query=query,
     )
 
     async with httpx.AsyncClient(verify=client.verify_ssl) as _client:
-        response = await _client.get(**kwargs)
+        response = await _client.request(**kwargs)
 
     return _build_response(response=response)
 
@@ -387,15 +488,39 @@ async def asyncio(
     company: Union[Getv3UsersCompanyType1, None, Unset, str] = UNSET,
     tag: Union[Getv3UsersTagType1, None, Unset, str] = UNSET,
     tags: Union[Unset, None, List[str]] = UNSET,
-    metadatakey: Union[Getv3UsersMetadatakeyType1, None, Unset, str] = UNSET,
-    metadatavalue: Union[Getv3UsersMetadatavalueType1, None, Unset, str] = UNSET,
+    metadata_key: Union[Getv3UsersMetadataKeyType1, None, Unset, str] = UNSET,
+    metadata_value: Union[Getv3UsersMetadataValueType1, None, Unset, str] = UNSET,
     product_id: Union[Unset, None, str] = UNSET,
-    activationapp_version: Union[Getv3UsersActivationappVersionType1, None, Unset, str] = UNSET,
+    activation_app_version: Union[Getv3UsersActivationAppVersionType1, None, Unset, str] = UNSET,
     created_at: Union[Getv3UsersCreatedAtType1, None, Unset, datetime.datetime] = UNSET,
     last_seen_at: Union[Getv3UsersLastSeenAtType1, None, Unset, datetime.datetime] = UNSET,
     query: Union[Unset, None, str] = UNSET,
 ) -> Optional[Union[HttpErrorResponseDto, List[UserDto]]]:
-    """Returns a list of users. The users are returned sorted by creation date in ascending order."""
+    """List all users
+
+     Returns a list of users. The users are returned sorted by creation date in ascending order.
+
+    Args:
+        page (Union[Unset, None, int]):
+        limit (Union[Unset, None, int]):
+        sort (Union[Unset, None, str]):
+        role (Union[Getv3UsersRoleType1, None, Unset, str]):
+        user_type (Union[Unset, None, str]):
+        email (Union[Getv3UsersEmailType1, None, Unset, str]):
+        company (Union[Getv3UsersCompanyType1, None, Unset, str]):
+        tag (Union[Getv3UsersTagType1, None, Unset, str]):
+        tags (Union[Unset, None, List[str]]):
+        metadata_key (Union[Getv3UsersMetadataKeyType1, None, Unset, str]):
+        metadata_value (Union[Getv3UsersMetadataValueType1, None, Unset, str]):
+        product_id (Union[Unset, None, str]):
+        activation_app_version (Union[Getv3UsersActivationAppVersionType1, None, Unset, str]):
+        created_at (Union[Getv3UsersCreatedAtType1, None, Unset, datetime.datetime]):
+        last_seen_at (Union[Getv3UsersLastSeenAtType1, None, Unset, datetime.datetime]):
+        query (Union[Unset, None, str]):
+
+    Returns:
+        Response[Union[HttpErrorResponseDto, List[UserDto]]]
+    """
 
     return (
         await asyncio_detailed(
@@ -409,10 +534,10 @@ async def asyncio(
             company=company,
             tag=tag,
             tags=tags,
-            metadatakey=metadatakey,
-            metadatavalue=metadatavalue,
+            metadata_key=metadata_key,
+            metadata_value=metadata_value,
             product_id=product_id,
-            activationapp_version=activationapp_version,
+            activation_app_version=activation_app_version,
             created_at=created_at,
             last_seen_at=last_seen_at,
             query=query,
