@@ -9,7 +9,10 @@ T = TypeVar("T", bound="AccessTokenDto")
 
 @attr.s(auto_attribs=True)
 class AccessTokenDto:
-    """ """
+    """
+    Attributes:
+        access_token (Union[Unset, None, str]):
+    """
 
     access_token: Union[Unset, None, str] = UNSET
 
