@@ -9,7 +9,10 @@ T = TypeVar("T", bound="AccountStatusRequestModel")
 
 @attr.s(auto_attribs=True)
 class AccountStatusRequestModel:
-    """ """
+    """
+    Attributes:
+        status (AccountStatusRequestModelStatus): Status of the account.
+    """
 
     status: AccountStatusRequestModelStatus
 
