@@ -9,7 +9,11 @@ T = TypeVar("T", bound="ActivationMeterAttributeDto")
 
 @attr.s(auto_attribs=True)
 class ActivationMeterAttributeDto:
-    """ """
+    """
+    Attributes:
+        name (Union[Unset, None, str]):
+        uses (Union[Unset, int]):
+    """
 
     name: Union[Unset, None, str] = UNSET
     uses: Union[Unset, int] = UNSET
