@@ -7,7 +7,11 @@ T = TypeVar("T", bound="ActivationMeterAttributeRequestModel")
 
 @attr.s(auto_attribs=True)
 class ActivationMeterAttributeRequestModel:
-    """ """
+    """
+    Attributes:
+        name (str): Name of the attribute.
+        uses_increment (int): Positive or negative increment to update the uses of the attribute.
+    """
 
     name: str
     uses_increment: int
