@@ -9,7 +9,10 @@ T = TypeVar("T", bound="ActivationTokenDto")
 
 @attr.s(auto_attribs=True)
 class ActivationTokenDto:
-    """ """
+    """
+    Attributes:
+        activation_token (Union[Unset, None, str]):
+    """
 
     activation_token: Union[Unset, None, str] = UNSET
 
