@@ -9,7 +9,11 @@ T = TypeVar("T", bound="ActivationsByAppVersionDto")
 
 @attr.s(auto_attribs=True)
 class ActivationsByAppVersionDto:
-    """ """
+    """
+    Attributes:
+        activations (Union[Unset, int]):
+        app_version (Union[Unset, None, str]):
+    """
 
     activations: Union[Unset, int] = UNSET
     app_version: Union[Unset, None, str] = UNSET
