@@ -9,7 +9,11 @@ T = TypeVar("T", bound="ActivationsByCountryDto")
 
 @attr.s(auto_attribs=True)
 class ActivationsByCountryDto:
-    """ """
+    """
+    Attributes:
+        activations (Union[Unset, int]):
+        country_code (Union[Unset, None, str]):
+    """
 
     activations: Union[Unset, int] = UNSET
     country_code: Union[Unset, None, str] = UNSET
