@@ -11,7 +11,11 @@ T = TypeVar("T", bound="ActivationsByDateDto")
 
 @attr.s(auto_attribs=True)
 class ActivationsByDateDto:
-    """ """
+    """
+    Attributes:
+        activations (Union[Unset, int]):
+        activated_at (Union[Unset, datetime.datetime]):
+    """
 
     activations: Union[Unset, int] = UNSET
     activated_at: Union[Unset, datetime.datetime] = UNSET
