@@ -10,7 +10,11 @@ T = TypeVar("T", bound="ActivationsByOsDto")
 
 @attr.s(auto_attribs=True)
 class ActivationsByOsDto:
-    """ """
+    """
+    Attributes:
+        activations (Union[Unset, int]):
+        os (Union[Unset, None, ActivationsByOsDtoOs]):
+    """
 
     activations: Union[Unset, int] = UNSET
     os: Union[Unset, None, ActivationsByOsDtoOs] = UNSET
