@@ -9,7 +9,11 @@ T = TypeVar("T", bound="ActivationsByOsVersionDto")
 
 @attr.s(auto_attribs=True)
 class ActivationsByOsVersionDto:
-    """ """
+    """
+    Attributes:
+        activations (Union[Unset, int]):
+        os_version (Union[Unset, None, str]):
+    """
 
     activations: Union[Unset, int] = UNSET
     os_version: Union[Unset, None, str] = UNSET
