@@ -9,7 +9,11 @@ T = TypeVar("T", bound="ActivationsByVmDto")
 
 @attr.s(auto_attribs=True)
 class ActivationsByVmDto:
-    """ """
+    """
+    Attributes:
+        activations (Union[Unset, int]):
+        vm_name (Union[Unset, None, str]):
+    """
 
     activations: Union[Unset, int] = UNSET
     vm_name: Union[Unset, None, str] = UNSET
