@@ -9,7 +9,12 @@ T = TypeVar("T", bound="ChangesDto")
 
 @attr.s(auto_attribs=True)
 class ChangesDto:
-    """ """
+    """
+    Attributes:
+        property_name (Union[Unset, None, str]):
+        old_value (Union[Unset, Any]):
+        new_value (Union[Unset, Any]):
+    """
 
     property_name: Union[Unset, None, str] = UNSET
     old_value: Union[Unset, Any] = UNSET
@@ -18,7 +23,6 @@ class ChangesDto:
     def to_dict(self) -> Dict[str, Any]:
         property_name = self.property_name
         old_value = self.old_value
-
         new_value = self.new_value
 
         field_dict: Dict[str, Any] = {}
