@@ -7,7 +7,12 @@ T = TypeVar("T", bound="CreditCardRequestModel")
 
 @attr.s(auto_attribs=True)
 class CreditCardRequestModel:
-    """ """
+    """
+    Attributes:
+        expiration_month (int): Credit card expiration month.
+        expiration_year (int): Credit card expiration year.
+        address_zip (str): Credit card address zip.
+    """
 
     expiration_month: int
     expiration_year: int
