@@ -9,7 +9,12 @@ T = TypeVar("T", bound="FeatureFlagRequestModel")
 
 @attr.s(auto_attribs=True)
 class FeatureFlagRequestModel:
-    """ """
+    """
+    Attributes:
+        name (Union[Unset, str]): Name for the feature flag.
+        description (Union[Unset, str]): Description for the feature flag.
+        product_id (Union[Unset, str]): Unique identifier for the product.
+    """
 
     name: Union[Unset, str] = UNSET
     description: Union[Unset, str] = UNSET
