@@ -9,7 +9,13 @@ T = TypeVar("T", bound="GoogleLoginRequestModel")
 
 @attr.s(auto_attribs=True)
 class GoogleLoginRequestModel:
-    """ """
+    """
+    Attributes:
+        company_id (Union[Unset, None, str]): Unique identifier of the company. Required for your employee/customer
+            login.
+        email (Union[Unset, str]): Email address of the user.
+        id_token (Union[Unset, str]): Google id token of the user.
+    """
 
     company_id: Union[Unset, None, str] = UNSET
     email: Union[Unset, str] = UNSET
