@@ -9,7 +9,11 @@ T = TypeVar("T", bound="HttpErrorResponseDto")
 
 @attr.s(auto_attribs=True)
 class HttpErrorResponseDto:
-    """ """
+    """
+    Attributes:
+        message (str): The error message.
+        code (Union[Unset, None, str]): The error code (conditional).
+    """
 
     message: str
     code: Union[Unset, None, str] = UNSET
