@@ -9,7 +9,11 @@ T = TypeVar("T", bound="IncrementMeterAttributeRequestModel")
 
 @attr.s(auto_attribs=True)
 class IncrementMeterAttributeRequestModel:
-    """ """
+    """
+    Attributes:
+        increment (Union[Unset, int]): Positive or negative increment to update the uses of the attribute.
+        activation_id (Union[Unset, str]): Unique identifier for the activation.
+    """
 
     increment: Union[Unset, int] = UNSET
     activation_id: Union[Unset, str] = UNSET
