@@ -18,7 +18,52 @@ T = TypeVar("T", bound="LicenseDto")
 
 @attr.s(auto_attribs=True)
 class LicenseDto:
-    """ """
+    """
+    Attributes:
+        id (Union[Unset, None, str]):
+        created_at (Union[Unset, datetime.datetime]):
+        updated_at (Union[Unset, datetime.datetime]):
+        key (Union[Unset, None, str]):
+        revoked (Union[Unset, bool]):
+        suspended (Union[Unset, bool]):
+        total_activations (Union[Unset, int]):
+        total_deactivations (Union[Unset, int]):
+        validity (Union[Unset, int]):
+        expiration_strategy (Union[Unset, None, LicenseDtoExpirationStrategy]):
+        fingerprint_matching_strategy (Union[Unset, None, LicenseDtoFingerprintMatchingStrategy]):
+        allowed_activations (Union[Unset, int]):
+        allowed_deactivations (Union[Unset, int]):
+        type (Union[Unset, None, LicenseDtoType]):
+        allowed_floating_clients (Union[Unset, int]):
+        server_sync_grace_period (Union[Unset, int]):
+        server_sync_interval (Union[Unset, int]):
+        allowed_clock_offset (Union[Unset, int]):
+        expiring_soon_event_offset (Union[Unset, int]):
+        lease_duration (Union[Unset, int]):
+        leasing_strategy (Union[Unset, None, LicenseDtoLeasingStrategy]):
+        expires_at (Union[Unset, None, datetime.datetime]):
+        allow_vm_activation (Union[Unset, bool]):
+        allow_container_activation (Union[Unset, bool]):
+        allow_client_lease_duration (Union[Unset, bool]):
+        user_locked (Union[Unset, bool]):
+        require_authentication (Union[Unset, bool]):
+        disable_geo_location (Union[Unset, bool]):
+        notes (Union[Unset, None, str]):
+        product_id (Union[Unset, None, str]):
+        product_version_id (Union[Unset, None, str]):
+        user (Union[Unset, UserDto]):
+        reseller (Union[Unset, UserDto]):
+        additional_user_ids (Union[Unset, None, List[str]]):
+        allowed_ip_range (Union[Unset, None, str]):
+        allowed_ip_ranges (Union[Unset, None, List[str]]):
+        allowed_ip_addresses (Union[Unset, None, List[str]]):
+        disallowed_ip_addresses (Union[Unset, None, List[str]]):
+        allowed_countries (Union[Unset, None, List[str]]):
+        disallowed_countries (Union[Unset, None, List[str]]):
+        metadata (Union[Unset, None, List[MetadataDto]]):
+        meter_attributes (Union[Unset, None, List[LicenseMeterAttributeDto]]):
+        tags (Union[Unset, None, List[str]]):
+    """
 
     id: Union[Unset, None, str] = UNSET
     created_at: Union[Unset, datetime.datetime] = UNSET
