@@ -9,7 +9,10 @@ T = TypeVar("T", bound="LicenseExtensionRequestModel")
 
 @attr.s(auto_attribs=True)
 class LicenseExtensionRequestModel:
-    """ """
+    """
+    Attributes:
+        extension_length (Union[Unset, int]): License extension duration (in seconds) to extend the license expiry.
+    """
 
     extension_length: Union[Unset, int] = UNSET
 
