@@ -9,7 +9,13 @@ T = TypeVar("T", bound="LicenseMeterAttributeRequestModel")
 
 @attr.s(auto_attribs=True)
 class LicenseMeterAttributeRequestModel:
-    """ """
+    """
+    Attributes:
+        name (str): Name of the attribute.
+        allowed_uses (int): Allowed number of uses for the attribute.
+        visible (Union[Unset, None, bool]): Set true to make the meter attribute visible to the user.
+        floating (Union[Unset, None, bool]): Set true to make the meter attribute floating.
+    """
 
     name: str
     allowed_uses: int
