@@ -15,7 +15,41 @@ T = TypeVar("T", bound="LicensePolicyDto")
 
 @attr.s(auto_attribs=True)
 class LicensePolicyDto:
-    """ """
+    """
+    Attributes:
+        id (Union[Unset, None, str]):
+        created_at (Union[Unset, datetime.datetime]):
+        updated_at (Union[Unset, datetime.datetime]):
+        name (Union[Unset, None, str]):
+        allow_vm_activation (Union[Unset, bool]):
+        allow_container_activation (Union[Unset, bool]):
+        user_locked (Union[Unset, bool]):
+        disable_geo_location (Union[Unset, bool]):
+        allowed_ip_range (Union[Unset, None, str]):
+        allowed_ip_ranges (Union[Unset, None, List[str]]):
+        allowed_countries (Union[Unset, None, List[str]]):
+        disallowed_countries (Union[Unset, None, List[str]]):
+        allowed_ip_addresses (Union[Unset, None, List[str]]):
+        disallowed_ip_addresses (Union[Unset, None, List[str]]):
+        validity (Union[Unset, int]):
+        expiration_strategy (Union[Unset, None, LicensePolicyDtoExpirationStrategy]):
+        fingerprint_matching_strategy (Union[Unset, None, LicensePolicyDtoFingerprintMatchingStrategy]):
+        allowed_activations (Union[Unset, int]):
+        allowed_deactivations (Union[Unset, int]):
+        type (Union[Unset, None, LicensePolicyDtoType]):
+        key_pattern (Union[Unset, None, str]):
+        lease_duration (Union[Unset, int]):
+        allow_client_lease_duration (Union[Unset, bool]):
+        leasing_strategy (Union[Unset, None, LicensePolicyDtoLeasingStrategy]):
+        allowed_floating_clients (Union[Unset, int]):
+        server_sync_grace_period (Union[Unset, int]):
+        server_sync_interval (Union[Unset, int]):
+        allowed_clock_offset (Union[Unset, int]):
+        expiring_soon_event_offset (Union[Unset, int]):
+        require_authentication (Union[Unset, bool]):
+        required_metadata_keys (Union[Unset, None, List[str]]):
+        required_meter_attributes (Union[Unset, None, List[str]]):
+    """
 
     id: Union[Unset, None, str] = UNSET
     created_at: Union[Unset, datetime.datetime] = UNSET
