@@ -9,7 +9,10 @@ T = TypeVar("T", bound="OfflineActivationDto")
 
 @attr.s(auto_attribs=True)
 class OfflineActivationDto:
-    """ """
+    """
+    Attributes:
+        offline_response (Union[Unset, None, str]):
+    """
 
     offline_response: Union[Unset, None, str] = UNSET
 
