@@ -9,7 +9,13 @@ T = TypeVar("T", bound="OfflineActivationRequestModel")
 
 @attr.s(auto_attribs=True)
 class OfflineActivationRequestModel:
-    """ """
+    """
+    Attributes:
+        offline_request (Union[Unset, str]): Encrypted offline activation request.
+        response_validity (Union[Unset, int]): The duration (in seconds) for which the offline response should remain
+            valid.
+        license_id (Union[Unset, str]): Unique identifier for the license.
+    """
 
     offline_request: Union[Unset, str] = UNSET
     response_validity: Union[Unset, int] = UNSET
