@@ -9,7 +9,11 @@ T = TypeVar("T", bound="OfflineDeactivationRequestRequestModel")
 
 @attr.s(auto_attribs=True)
 class OfflineDeactivationRequestRequestModel:
-    """ """
+    """
+    Attributes:
+        offline_request (Union[Unset, str]): Encrypted offline deactivation request.
+        license_id (Union[Unset, str]): Unique identifier for the license.
+    """
 
     offline_request: Union[Unset, str] = UNSET
     license_id: Union[Unset, str] = UNSET
