@@ -9,7 +9,13 @@ T = TypeVar("T", bound="OfflineTrialActivationRequestModel")
 
 @attr.s(auto_attribs=True)
 class OfflineTrialActivationRequestModel:
-    """ """
+    """
+    Attributes:
+        offline_request (Union[Unset, str]): Encrypted offline trial activation request.
+        response_validity (Union[Unset, int]): The duration (in seconds) for which the offline response should remain
+            valid.
+        product_id (Union[Unset, str]): Unique identifier for the product.
+    """
 
     offline_request: Union[Unset, str] = UNSET
     response_validity: Union[Unset, int] = UNSET
