@@ -9,7 +9,10 @@ T = TypeVar("T", bound="PaymentMethodTokenRequestModel")
 
 @attr.s(auto_attribs=True)
 class PaymentMethodTokenRequestModel:
-    """ """
+    """
+    Attributes:
+        token (Union[Unset, str]): Token to validate payment method details.
+    """
 
     token: Union[Unset, str] = UNSET
 
