@@ -7,7 +7,10 @@ T = TypeVar("T", bound="PersonalAccessTokenRevokeRequestModel")
 
 @attr.s(auto_attribs=True)
 class PersonalAccessTokenRevokeRequestModel:
-    """ """
+    """
+    Attributes:
+        revoked (bool): Set true to revoke the token.
+    """
 
     revoked: bool
 
