@@ -7,7 +7,10 @@ T = TypeVar("T", bound="PlanUpdateRequestModel")
 
 @attr.s(auto_attribs=True)
 class PlanUpdateRequestModel:
-    """ """
+    """
+    Attributes:
+        plan_id (str): Unique identifier for the plan.
+    """
 
     plan_id: str
 
