@@ -15,7 +15,51 @@ T = TypeVar("T", bound="Postv3LicensePoliciesJsonBody")
 
 @attr.s(auto_attribs=True)
 class Postv3LicensePoliciesJsonBody:
-    """ """
+    """
+    Attributes:
+        name (Union[Unset, str]): Name for the policy.
+        fingerprint_matching_strategy (Union[Unset, LicensePolicyRequestModelFingerprintMatchingStrategy]): Strategy for
+            matching machine fingerprint.
+        allow_vm_activation (Union[Unset, bool]): Whether to allow an activation inside a virtual machine.
+        allow_container_activation (Union[Unset, bool]): Whether to allow an activation inside a container.
+        user_locked (Union[Unset, bool]): Locks the activation to the machine user.
+        disable_geo_location (Union[Unset, bool]): Whether IP address and geo-location should be stored.
+        allowed_ip_range (Union[Unset, None, str]): Allowed IP range. Leave empty to ignore.
+        allowed_ip_ranges (Union[Unset, None, List[str]]): Allowed IP ranges. Leave empty to ignore.
+        allowed_countries (Union[Unset, None, List[str]]): List of the allowed countries. Leave empty to ignore.
+        disallowed_countries (Union[Unset, None, List[str]]): List of the disallowed countries. Leave empty to ignore.
+        allowed_ip_addresses (Union[Unset, None, List[str]]): List of the allowed ip addresses. Leave empty to ignore.
+        disallowed_ip_addresses (Union[Unset, None, List[str]]): List of the disallowed ip addresses. Leave empty to
+            ignore.
+        validity (Union[Unset, int]): The duration after which the license will expire. Set to '0' for no expiry.
+        expiration_strategy (Union[Unset, LicensePolicyRequestModelExpirationStrategy]): The strategy to determine the
+            expiration start date.
+        allowed_activations (Union[Unset, int]): Allowed number of activations for the license. Set to '0' for unlimited
+            activations.
+        allowed_deactivations (Union[Unset, int]): Allowed number of deactivations for the license. This setting is
+            ignored for floating licenses.
+        type (Union[Unset, LicensePolicyRequestModelType]): Type of the license key.
+        key_pattern (Union[Unset, None, str]): Regex for the license key pattern.
+        lease_duration (Union[Unset, None, int]): Duration of lease for floating licenses. Set to '0' for unlimited
+            lease duration.
+        allow_client_lease_duration (Union[Unset, bool]): Allow client to set the lease duration for floating licenses.
+        leasing_strategy (Union[Unset, None, LicensePolicyRequestModelLeasingStrategy]): Leasing strategy for floating
+            licenses.
+        allowed_floating_clients (Union[Unset, None, int]): Allowed number of floating clients for on-premise
+            LexFloatServer.
+        server_sync_grace_period (Union[Unset, int]): The duration for which the server sync failure due to network
+            error is acceptable.
+        server_sync_interval (Union[Unset, int]): The interval at which license data in client is synced with the
+            server.
+        allowed_clock_offset (Union[Unset, int]): The allowed clock offset between the network time and the local time.
+        expiring_soon_event_offset (Union[Unset, int]): The number of seconds to wait before license expiration date to
+            trigger 'license.expiring-soon' webhook event.
+        require_authentication (Union[Unset, bool]): Whether user authentication is required for license activation.
+        required_metadata_keys (Union[Unset, None, List[str]]): List of required metadata keys which a license must
+            have.
+        required_meter_attributes (Union[Unset, None, List[str]]): List of required meter attributes which a license
+            must have.
+    """
 
     name: Union[Unset, str] = UNSET
     fingerprint_matching_strategy: Union[Unset, LicensePolicyRequestModelFingerprintMatchingStrategy] = UNSET
