@@ -7,7 +7,12 @@ T = TypeVar("T", bound="ProductMetadataRequestModel")
 
 @attr.s(auto_attribs=True)
 class ProductMetadataRequestModel:
-    """ """
+    """
+    Attributes:
+        key (str): Name of the key.
+        value (str): Value of the key.
+        visible (bool): Set true to access the metadata on activation.
+    """
 
     key: str
     value: str
