@@ -9,7 +9,12 @@ T = TypeVar("T", bound="ProductVersionFeatureFlagRequestModel")
 
 @attr.s(auto_attribs=True)
 class ProductVersionFeatureFlagRequestModel:
-    """ """
+    """
+    Attributes:
+        name (str): Name of the feature.
+        enabled (bool): Whether the feature is enabled.
+        data (Union[Unset, None, str]): Optional data associated with the feature flag.
+    """
 
     name: str
     enabled: bool
