@@ -9,7 +9,11 @@ T = TypeVar("T", bound="ResetPasswordRequestModel")
 
 @attr.s(auto_attribs=True)
 class ResetPasswordRequestModel:
-    """ """
+    """
+    Attributes:
+        new_password (Union[Unset, str]): New password of the user.
+        token (Union[Unset, str]): Password reset token.
+    """
 
     new_password: Union[Unset, str] = UNSET
     token: Union[Unset, str] = UNSET
