@@ -9,7 +9,10 @@ T = TypeVar("T", bound="ResetPasswordTokenDto")
 
 @attr.s(auto_attribs=True)
 class ResetPasswordTokenDto:
-    """ """
+    """
+    Attributes:
+        reset_password_token (Union[Unset, None, str]):
+    """
 
     reset_password_token: Union[Unset, None, str] = UNSET
 
