@@ -9,7 +9,12 @@ T = TypeVar("T", bound="RoleRequestModel")
 
 @attr.s(auto_attribs=True)
 class RoleRequestModel:
-    """ """
+    """
+    Attributes:
+        name (Union[Unset, str]): Name for the role.
+        description (Union[Unset, None, str]): Description for the role.
+        claims (Union[Unset, List[str]]): List of permission claims for the role.
+    """
 
     name: Union[Unset, str] = UNSET
     description: Union[Unset, None, str] = UNSET
