@@ -7,7 +7,11 @@ T = TypeVar("T", bound="SamlRoleMappingRequestModel")
 
 @attr.s(auto_attribs=True)
 class SamlRoleMappingRequestModel:
-    """ """
+    """
+    Attributes:
+        identity_provider_role (str): Identity provider role.
+        service_provider_role (str): Service provider role.
+    """
 
     identity_provider_role: str
     service_provider_role: str
