@@ -9,7 +9,10 @@ T = TypeVar("T", bound="SsoLoginRequestModel")
 
 @attr.s(auto_attribs=True)
 class SsoLoginRequestModel:
-    """ """
+    """
+    Attributes:
+        company_id (Union[Unset, str]): Unique identifier of the company.
+    """
 
     company_id: Union[Unset, str] = UNSET
 
