@@ -9,7 +9,11 @@ T = TypeVar("T", bound="TagRequestModel")
 
 @attr.s(auto_attribs=True)
 class TagRequestModel:
-    """ """
+    """
+    Attributes:
+        name (Union[Unset, str]): Name for the tag.
+        description (Union[Unset, str]): Description for the tag.
+    """
 
     name: Union[Unset, str] = UNSET
     description: Union[Unset, str] = UNSET
