@@ -7,7 +7,11 @@ T = TypeVar("T", bound="TrialActivationMetadataRequestModel")
 
 @attr.s(auto_attribs=True)
 class TrialActivationMetadataRequestModel:
-    """ """
+    """
+    Attributes:
+        key (str): Name of the key.
+        value (str): Value of the key.
+    """
 
     key: str
     value: str
