@@ -9,7 +9,10 @@ T = TypeVar("T", bound="TrialActivationTokenDto")
 
 @attr.s(auto_attribs=True)
 class TrialActivationTokenDto:
-    """ """
+    """
+    Attributes:
+        trial_activation_token (Union[Unset, None, str]):
+    """
 
     trial_activation_token: Union[Unset, None, str] = UNSET
 
