@@ -9,7 +9,10 @@ T = TypeVar("T", bound="TrialExtensionRequestModel")
 
 @attr.s(auto_attribs=True)
 class TrialExtensionRequestModel:
-    """ """
+    """
+    Attributes:
+        extension_length (Union[Unset, int]): Trial extension duration (in seconds) to extend the trial expiry.
+    """
 
     extension_length: Union[Unset, int] = UNSET
 
