@@ -9,7 +9,10 @@ T = TypeVar("T", bound="TwoFactorRecoveryCodesDto")
 
 @attr.s(auto_attribs=True)
 class TwoFactorRecoveryCodesDto:
-    """ """
+    """
+    Attributes:
+        recovery_codes (Union[Unset, None, List[str]]):
+    """
 
     recovery_codes: Union[Unset, None, List[str]] = UNSET
 
