@@ -9,7 +9,11 @@ T = TypeVar("T", bound="TwoFactorSecretDto")
 
 @attr.s(auto_attribs=True)
 class TwoFactorSecretDto:
-    """ """
+    """
+    Attributes:
+        email (Union[Unset, None, str]):
+        url (Union[Unset, None, str]):
+    """
 
     email: Union[Unset, None, str] = UNSET
     url: Union[Unset, None, str] = UNSET
