@@ -9,7 +9,11 @@ T = TypeVar("T", bound="UserEmailRequestModel")
 
 @attr.s(auto_attribs=True)
 class UserEmailRequestModel:
-    """ """
+    """
+    Attributes:
+        company_id (Union[Unset, None, str]): Unique company identifier.
+        email (Union[Unset, str]): Email address of the user.
+    """
 
     company_id: Union[Unset, None, str] = UNSET
     email: Union[Unset, str] = UNSET
