@@ -9,7 +9,11 @@ T = TypeVar("T", bound="UserPasswordRequestModel")
 
 @attr.s(auto_attribs=True)
 class UserPasswordRequestModel:
-    """ """
+    """
+    Attributes:
+        old_password (Union[Unset, str]): Old password of the user.
+        new_password (Union[Unset, str]): New password of the user.
+    """
 
     old_password: Union[Unset, str] = UNSET
     new_password: Union[Unset, str] = UNSET
