@@ -9,7 +9,10 @@ T = TypeVar("T", bound="UserProductDto")
 
 @attr.s(auto_attribs=True)
 class UserProductDto:
-    """ """
+    """
+    Attributes:
+        display_name (Union[Unset, None, str]):
+    """
 
     display_name: Union[Unset, None, str] = UNSET
 
